@@ -110,9 +110,15 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # The bandwidth package ID is not supported in this account.
 INVALIDPARAMETERVALUE_ACCOUNTNOTSUPPORTBANDWIDTHPACKAGEID = 'InvalidParameterValue.AccountNotSupportBandwidthPackageId'
 
+# The declared original expected instance number does not match the actual original expected instance number.
+INVALIDPARAMETERVALUE_ASSERTDESIREDCAPACITYFAILED = 'InvalidParameterValue.AssertDesiredCapacityFailed'
+
 # The specified base capacity cannot exceed the max capacity.
 INVALIDPARAMETERVALUE_BASECAPACITYTOOLARGE = 'InvalidParameterValue.BaseCapacityTooLarge'
 
+# The batch count cannot exceed the total number of instances pending refresh.
+INVALIDPARAMETERVALUE_BATCHNUMBERTOOLARGE = 'InvalidParameterValue.BatchNumberTooLarge'
+
 # A classic CLB should be specified.
 INVALIDPARAMETERVALUE_CLASSICLB = 'InvalidParameterValue.ClassicLb'
 
@@ -149,6 +155,9 @@ INVALIDPARAMETERVALUE_GROUPNAMEDUPLICATED = 'InvalidParameterValue.GroupNameDupl
 # Invalid hostname
 INVALIDPARAMETERVALUE_HOSTNAMEILLEGAL = 'InvalidParameterValue.HostNameIllegal'
 
+# HostNames with suffixes are too long and exceed the specified upper limit.
+INVALIDPARAMETERVALUE_HOSTNAMEWITHSUFFIXTOOLONG = 'InvalidParameterValue.HostNameWithSuffixTooLong'
+
 # The specified IPv6 public network bandwidth billing mode is invalid.
 INVALIDPARAMETERVALUE_IPV6INTERNETCHARGETYPE = 'InvalidParameterValue.IPv6InternetChargeType'
 
@@ -158,6 +167,9 @@ INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'
 # Invalid instance name
 INVALIDPARAMETERVALUE_INSTANCENAMEILLEGAL = 'InvalidParameterValue.InstanceNameIllegal'
 
+# Instance names with suffixes are too long and exceed the specified upper limit.
+INVALIDPARAMETERVALUE_INSTANCENAMEWITHSUFFIXTOOLONG = 'InvalidParameterValue.InstanceNameWithSuffixTooLong'
+
 # The instance type is not supported.
 INVALIDPARAMETERVALUE_INSTANCETYPENOTSUPPORTED = 'InvalidParameterValue.InstanceTypeNotSupported'
 
@@ -371,6 +383,9 @@ RESOURCEINSUFFICIENT_INSERVICEINSTANCEABOVEMAXSIZE = 'ResourceInsufficient.InSer
 # The number of instances in a scaling group is less than the minimum capacity.
 RESOURCEINSUFFICIENT_INSERVICEINSTANCEBELOWMINSIZE = 'ResourceInsufficient.InServiceInstanceBelowMinSize'
 
+# The scaling group does not exist.
+RESOURCENOTFOUND_AUTOSCALINGGROUPIDNOTFOUND = 'ResourceNotFound.AutoScalingGroupIdNotFound'
+
 # The scaling group does not exist.
 RESOURCENOTFOUND_AUTOSCALINGGROUPNOTFOUND = 'ResourceNotFound.AutoScalingGroupNotFound'
 
@@ -419,6 +434,9 @@ RESOURCENOTFOUND_LOADBALANCERNOTINAUTOSCALINGGROUP = 'ResourceNotFound.LoadBalan
 # The specified location does not exist.
 RESOURCENOTFOUND_LOCATIONNOTFOUND = 'ResourceNotFound.LocationNotFound'
 
+# The specified instance refresh activity does not exist.
+RESOURCENOTFOUND_REFRESHACTIVITYNOTFOUND = 'ResourceNotFound.RefreshActivityNotFound'
+
 # The alarm policy does not exist.
 RESOURCENOTFOUND_SCALINGPOLICYNOTFOUND = 'ResourceNotFound.ScalingPolicyNotFound'
 
@@ -440,6 +458,9 @@ RESOURCEUNAVAILABLE_AUTOSCALINGGROUPDISABLED = 'ResourceUnavailable.AutoScalingG
 # The auto scaling group is active.
 RESOURCEUNAVAILABLE_AUTOSCALINGGROUPINACTIVITY = 'ResourceUnavailable.AutoScalingGroupInActivity'
 
+# The scaling group is already involved in another instance refresh activity.
+RESOURCEUNAVAILABLE_AUTOSCALINGGROUPINREFRESHACTIVITY = 'ResourceUnavailable.AutoScalingGroupInRefreshActivity'
+
 # There are no subscribers for the specified CMQ topic.
 RESOURCEUNAVAILABLE_CMQTOPICHASNOSUBSCRIBER = 'ResourceUnavailable.CmqTopicHasNoSubscriber'
 
@@ -449,6 +470,9 @@ RESOURCEUNAVAILABLE_CVMVPCINCONSISTENT = 'ResourceUnavailable.CvmVpcInconsistent
 # You cannot modify the VPC of a scaling group bound with a load balancer.
 RESOURCEUNAVAILABLE_FORBIDDENMODIFYVPC = 'ResourceUnavailable.ForbiddenModifyVpc'
 
+# The instance reinstallation quotation failed, because the new image conflicts with other parameters of the instance or the new image does not exist.
+RESOURCEUNAVAILABLE_INQUIRYPRICERESETINSTANCEFAILED = 'ResourceUnavailable.InquiryPriceResetInstanceFailed'
+
 # Unable to add the instance to the scaling group.
 RESOURCEUNAVAILABLE_INSTANCECANNOTATTACH = 'ResourceUnavailable.InstanceCannotAttach'
 
@@ -479,9 +503,24 @@ RESOURCEUNAVAILABLE_LIFECYCLEACTIONRESULTHASSET = 'ResourceUnavailable.Lifecycle
 # CLB is active in the scaling group.
 RESOURCEUNAVAILABLE_LOADBALANCERINOPERATION = 'ResourceUnavailable.LoadBalancerInOperation'
 
+# There are no instances in running status within the scaling group, making it impossible to perform an instance refresh.
+RESOURCEUNAVAILABLE_NOINSTANCECANREFRESH = 'ResourceUnavailable.NoInstanceCanRefresh'
+
+# There are no instances eligible for rollback in the scaling group.
+RESOURCEUNAVAILABLE_NOINSTANCECANROLLBACK = 'ResourceUnavailable.NoInstanceCanRollback'
+
 # Project inconsistency.
 RESOURCEUNAVAILABLE_PROJECTINCONSISTENT = 'ResourceUnavailable.ProjectInconsistent'
 
+# The current refresh activity is in a successful status and not the most recent execution, so it cannot be rolled back.
+RESOURCEUNAVAILABLE_REFRESHACTIVITYCANNOTROLLBACK = 'ResourceUnavailable.RefreshActivityCanNotRollback'
+
+# The instance refresh activity status conflicts with the current operation.
+RESOURCEUNAVAILABLE_REFRESHACTIVITYSTATUSCONFLICTWITHOPERATION = 'ResourceUnavailable.RefreshActivityStatusConflictWithOperation'
+
+# Rollback type instance refresh activity cannot be rolled back again.
+RESOURCEUNAVAILABLE_ROLLBACKTYPEACTIVITYCANNOTROLLBACKAGAIN = 'ResourceUnavailable.RollbackTypeActivityCanNotRollbackAgain'
+
 # Unable to add instances to the scaling group when they are shut down.
 RESOURCEUNAVAILABLE_STOPPEDINSTANCENOTALLOWATTACH = 'ResourceUnavailable.StoppedInstanceNotAllowAttach'
 
