@@ -77,6 +77,9 @@ FAILEDOPERATION_INSTANCETASKCONFLICTERROR = 'FailedOperation.InstanceTaskConflic
 # Failed to deserialize JSON.
 FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'
 
+# 
+FAILEDOPERATION_LOGCONTENTOVERLIMIT = 'FailedOperation.LogContentOverLimit'
+
 # No policy modification detected
 FAILEDOPERATION_NOTCHANGESTRATEGY = 'FailedOperation.NotChangeStrategy'
 
