@@ -85,6 +85,10 @@ class AbstractClient(object):
             if self.profile.region_breaker_profile is None:
                 self.profile.region_breaker_profile = RegionBreakerProfile()
             self.circuit_breaker = CircuitBreaker(self.profile.region_breaker_profile)
+        if self.profile.request_client:
+            self.request_client = self._sdkVersion + "; " + self.profile.request_client
+        else:
+            self.request_client = self._sdkVersion
 
     def _fix_params(self, params):
         if not isinstance(params, (dict,)):
@@ -134,7 +138,7 @@ class AbstractClient(object):
     def _build_req_with_old_signature(self, action, params, req):
         params = copy.deepcopy(self._fix_params(params))
         params['Action'] = action[0].upper() + action[1:]
-        params['RequestClient'] = self._sdkVersion
+        params['RequestClient'] = self.request_client
         params['Nonce'] = random.randint(1, sys.maxsize)
         params['Timestamp'] = int(time.time())
         params['Version'] = self._apiVersion
@@ -183,7 +187,7 @@ class AbstractClient(object):
         timestamp = int(time.time())
         req.header["Host"] = endpoint
         req.header["X-TC-Action"] = action[0].upper() + action[1:]
-        req.header["X-TC-RequestClient"] = self._sdkVersion
+        req.header["X-TC-RequestClient"] = self.request_client
         req.header["X-TC-Timestamp"] = str(timestamp)
         req.header["X-TC-Version"] = self._apiVersion
         if self.profile.unsignedPayload is True:
@@ -274,7 +278,7 @@ class AbstractClient(object):
         timestamp = int(time.time())
         req.header["Host"] = endpoint
         req.header["X-TC-Action"] = action[0].upper() + action[1:]
-        req.header["X-TC-RequestClient"] = self._sdkVersion
+        req.header["X-TC-RequestClient"] = self.request_client
         req.header["X-TC-Timestamp"] = str(timestamp)
         req.header["X-TC-Version"] = self._apiVersion
         if self.profile.unsignedPayload is True:
@@ -392,6 +396,12 @@ class AbstractClient(object):
                 e[key] = int(val)
 
     def _call(self, action, params, options=None, headers=None):
+        if headers is None:
+            headers = {}
+        if not isinstance(headers, dict):
+            raise TencentCloudSDKException("ClientError", "headers must be a dict.")
+        if "x-tc-traceid" not in {k.lower() for k in headers.keys()}:
+            headers["X-TC-TraceId"] = str(uuid.uuid4())
         if not self.profile.disable_region_breaker:
             return self._call_with_region_breaker(action, params, options, headers)
         req = RequestInternal(self._get_endpoint(),
