@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# Operation failed
+FAILEDOPERATION = 'FailedOperation'
+
 # Batch query failed
 FAILEDOPERATION_BATCHGETINSTANCEERROR = 'FailedOperation.BatchGetInstanceError'
 
@@ -89,7 +92,7 @@ INTERNALERROR_GETSUBNETFAILED = 'InternalError.GetSubnetFailed'
 # Failed to get the VPC.
 INTERNALERROR_GETVPCFAILED = 'InternalError.GetVpcFailed'
 
-# 
+# Network error
 INTERNALERROR_HTTPERROR = 'InternalError.HttpError'
 
 # An exception occurred while executing the HTTP request.
@@ -200,6 +203,9 @@ INVALIDPARAMETERVALUE_PARAMETEROUTRANGEERROR = 'InvalidParameterValue.ParameterO
 # This operation is not allowed for monthly-subscribed instances.
 INVALIDPARAMETERVALUE_PREPAYPAYMODEERROR = 'InvalidParameterValue.PrePayPayModeError'
 
+# The `ProjectId` was not found.
+INVALIDPARAMETERVALUE_PROJECTIDNOTFOUND = 'InvalidParameterValue.ProjectIdNotFound'
+
 # The selected region and AZ are unavailable.
 INVALIDPARAMETERVALUE_REGIONZONEUNAVAILABLE = 'InvalidParameterValue.RegionZoneUnavailable'
 
