@@ -80,6 +80,9 @@ INTERNALERROR_OSSEXCEPTION = 'InternalError.OssException'
 # Service error. Please try again. If the problem persists, please submit a ticket.
 INTERNALERROR_SYSTEM = 'InternalError.System'
 
+# 
+INTERNALERROR_UNKNOWNINTERNALERROR = 'InternalError.UnknownInternalError'
+
 # Parameter error.
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -92,6 +95,9 @@ INVALIDPARAMETER_PAYLOAD = 'InvalidParameter.Payload'
 # The `AMPParams` value does not conform to the specification. Please fix it and try again.
 INVALIDPARAMETERVALUE_AMPPARAMS = 'InvalidParameterValue.AMPParams'
 
+# The `Action` value is invalid.
+INVALIDPARAMETERVALUE_ACTION = 'InvalidParameterValue.Action'
+
 # The `BatchEventCount` value does not conform to the specification. Please fix it and try again.
 INVALIDPARAMETERVALUE_BATCHEVENTCOUNT = 'InvalidParameterValue.BatchEventCount'
 
