@@ -56,6 +56,12 @@ FAILEDOPERATION_COMPARELOWSIMILARITY = 'FailedOperation.CompareLowSimilarity'
 # Error calling the comparison engine API.
 FAILEDOPERATION_COMPARESYSTEMERROR = 'FailedOperation.CompareSystemError'
 
+# The face in the picture is blocked, please upload a picture without any blockage
+FAILEDOPERATION_COVEREDFACE = 'FailedOperation.CoveredFace'
+
+# The service engine call failed, please try again
+FAILEDOPERATION_DETECTENGINESYSTEMERROR = 'FailedOperation.DetectEngineSystemError'
+
 # File download failed.
 FAILEDOPERATION_DOWNLOADERROR = 'FailedOperation.DownLoadError'
 
@@ -71,6 +77,9 @@ FAILEDOPERATION_IMAGEDECODEFAILED = 'FailedOperation.ImageDecodeFailed'
 # The image is too large.
 FAILEDOPERATION_IMAGESIZETOOLARGE = 'FailedOperation.ImageSizeTooLarge'
 
+# No complete face was detected. Please enter a complete face image.
+FAILEDOPERATION_INCOMPLETEFACE = 'FailedOperation.IncompleteFace'
+
 # Multiple faces are detected.
 FAILEDOPERATION_LIFEPHOTODETECTFACES = 'FailedOperation.LifePhotoDetectFaces'
 
@@ -128,6 +137,9 @@ FAILEDOPERATION_LIVESSSYSTEMERROR = 'FailedOperation.LivessSystemError'
 # Video-based real person detection failed.
 FAILEDOPERATION_LIVESSUNKNOWNERROR = 'FailedOperation.LivessUnknownError'
 
+# The image quality is too poor, please check the image quality
+FAILEDOPERATION_POORIMAGEQUALITY = 'FailedOperation.PoorImageQuality'
+
 # Real person detection failed.
 FAILEDOPERATION_SILENTDETECTFAIL = 'FailedOperation.SilentDetectFail'
 
@@ -158,9 +170,18 @@ FAILEDOPERATION_SILENTTHRESHOLD = 'FailedOperation.SilentThreshold'
 # The video is too short. Please capture a video longer than 2 seconds.
 FAILEDOPERATION_SILENTTOOSHORT = 'FailedOperation.SilentTooShort'
 
+# Unknown error.
+FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'
+
 # Unknown internal error.
 FAILEDOPERATION_UNKNOWN = 'FailedOperation.UnKnown'
 
+# The service is not activated.
+FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'
+
+# Video decoding abnormality
+FAILEDOPERATION_VIDEODECODEFAILED = 'FailedOperation.VideoDecodeFailed'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
@@ -188,6 +209,9 @@ INTERNALERROR_UNKNOWN = 'InternalError.UnKnown'
 # Invalid parameter.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# Image decoding failed.
+INVALIDPARAMETER_ENGINEIMAGEDECODEFAILED = 'InvalidParameter.EngineImageDecodeFailed'
+
 # Incorrect parameter value.
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
@@ -197,12 +221,27 @@ INVALIDPARAMETERVALUE_BIZTOKENEXPIRED = 'InvalidParameterValue.BizTokenExpired'
 # Invalid BizToken.
 INVALIDPARAMETERVALUE_BIZTOKENILLEGAL = 'InvalidParameterValue.BizTokenIllegal'
 
+# The image file content size is abnormal.
+INVALIDPARAMETERVALUE_INVALIDFILECONTENTSIZE = 'InvalidParameterValue.InvalidFileContentSize'
+
+# Parameter value is wrong.
+INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'
+
 # Operation denied.
 OPERATIONDENIED = 'OperationDenied'
 
 # The resource is unavailable.
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# Image file download failed.
+RESOURCEUNAVAILABLE_IMAGEDOWNLOADERROR = 'ResourceUnavailable.ImageDownloadError'
+
+# The account is in arrears.
+RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'
+
+# The account has exhausted the resource package for this service.
+RESOURCEUNAVAILABLE_RESOURCEPACKAGERUNOUT = 'ResourceUnavailable.ResourcePackageRunOut'
+
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
@@ -215,6 +254,9 @@ UNAUTHORIZEDOPERATION_ACTIVATING = 'UnauthorizedOperation.Activating'
 # The account is in arrears.
 UNAUTHORIZEDOPERATION_ARREARS = 'UnauthorizedOperation.Arrears'
 
+# The billing status is abnormal.
+UNAUTHORIZEDOPERATION_CHARGESTATUSEXCEPTION = 'UnauthorizedOperation.ChargeStatusException'
+
 # Identity verification has not been completed for the account.
 UNAUTHORIZEDOPERATION_NONAUTHORIZE = 'UnauthorizedOperation.NonAuthorize'
 
