@@ -83,9 +83,15 @@ INVALIDPARAMETERVALUE_COUNTRYCODEEMPTY = 'InvalidParameterValue.CountryCodeEmpty
 # The credit quota has exceeded the limit with the newly allocated quota.
 INVALIDPARAMETERVALUE_CREDITAMOUNTOUTOFRANGE = 'InvalidParameterValue.CreditAmountOutOfRange'
 
+# The dimension data entered is incorrect.
+INVALIDPARAMETERVALUE_INVALIDDIMENSION = 'InvalidParameterValue.InvalidDimension'
+
 # Incorrect month value
 INVALIDPARAMETERVALUE_INVALIDMONTH = 'InvalidParameterValue.InvalidMonth'
 
+# InvalidParameterValue.InvalidUin
+INVALIDPARAMETERVALUE_INVALIDUIN = 'InvalidParameterValue.InvalidUin'
+
 # InvalidParameterValue.MailEmpty
 INVALIDPARAMETERVALUE_MAILEMPTY = 'InvalidParameterValue.MailEmpty'
 
