@@ -26,6 +26,29 @@ class IntlpartnersmgtClient(AbstractClient):
     _service = 'intlpartnersmgt'
 
 
+    def AllocateCreditPool(self, request):
+        """This API is used to allocate credit pools to second-level resellers by distributors.
+
+        :param request: Request instance for AllocateCreditPool.
+        :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.AllocateCreditPoolRequest`
+        :rtype: :class:`tencentcloud.intlpartnersmgt.v20220928.models.AllocateCreditPoolResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AllocateCreditPool", params, headers=headers)
+            response = json.loads(body)
+            model = models.AllocateCreditPoolResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def AllocateCustomerCredit(self, request):
         """This API is used for a partner to set credit for a customer, such as increasing or lowering the credit and setting it to 0.
         1. The credit is valid permanently and will not be zeroed regularly.
@@ -54,11 +77,7 @@ class IntlpartnersmgtClient(AbstractClient):
 
 
     def CreateAccount(self, request):
-        """This API is used to create a Tencent Cloud account on the partner platform for a customer. After registration, the customer will be automatically bound to the partner account.
-
-        Notes:<br>
-        1. The partner should verify the entered email address and mobile number for creating a Tencent Cloud account.<br>
-        2. The customer needs to complete personal information after the first login.
+        """This API is used to create Tencent Cloud customer accounts for first-level resellers/second-level resellers. After the account is created, it will be automatically bound to the partner account.Note:1. Create a Tencent Cloud account. The entered email address and mobile phone number need to be verified by the partner for validity.2. Customers need to add personal information when logging in for the first time.3. This interface needs to be applied for allowlist usage. Please contact the channel manager to initiate the application process.
 
         :param request: Request instance for CreateAccount.
         :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.CreateAccountRequest`
@@ -81,7 +100,7 @@ class IntlpartnersmgtClient(AbstractClient):
 
 
     def DescribeBillDetail(self, request):
-        """This API is used to query the customer bill details.
+        """This API is used to query bill details by customers.
 
         :param request: Request instance for DescribeBillDetail.
         :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeBillDetailRequest`
@@ -103,6 +122,52 @@ class IntlpartnersmgtClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBillDownloadUrl(self, request):
+        """This API is used to download billing files and return billing file URLs by customers.
+
+        :param request: Request instance for DescribeBillDownloadUrl.
+        :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeBillDownloadUrlRequest`
+        :rtype: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeBillDownloadUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillDownloadUrl", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillDownloadUrlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBillSummary(self, request):
+        """External API for the L1 billing of the customer billing center
+
+        :param request: Request instance for DescribeBillSummary.
+        :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeBillSummaryRequest`
+        :rtype: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeBillSummaryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillSummary", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillSummaryResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBillSummaryByPayMode(self, request):
         """This API is used to obtain the total amount of customer bills by payment mode.
 
@@ -173,7 +238,7 @@ class IntlpartnersmgtClient(AbstractClient):
 
 
     def DescribeCustomerBillDetail(self, request):
-        """This API is used to query the customer bill details.
+        """This API is used to query the customer bill details by resellers.
 
         :param request: Request instance for DescribeCustomerBillDetail.
         :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.DescribeCustomerBillDetailRequest`
@@ -287,6 +352,29 @@ class IntlpartnersmgtClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyClientRemark(self, request):
+        """This API is used to modify customer remarks.
+
+        :param request: Request instance for ModifyClientRemark.
+        :type request: :class:`tencentcloud.intlpartnersmgt.v20220928.models.ModifyClientRemarkRequest`
+        :rtype: :class:`tencentcloud.intlpartnersmgt.v20220928.models.ModifyClientRemarkResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyClientRemark", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyClientRemarkResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def QueryAccountVerificationStatus(self, request):
         """This API is used to query the account verification status.
 
