@@ -994,7 +994,7 @@ class KmsClient(AbstractClient):
 
 
     def PostQuantumCryptoDecrypt(self, request):
-        """u200dThis API u200dis used to decrypt ciphertext using post-quantum cryptography (PQC) algorithm, and return the plaintext.
+        """This API is used to decrypt ciphertext using post-quantum cryptography (PQC) algorithm, and return the plaintext.
 
         :param request: Request instance for PostQuantumCryptoDecrypt.
         :type request: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoDecryptRequest`
@@ -1017,7 +1017,7 @@ class KmsClient(AbstractClient):
 
 
     def PostQuantumCryptoEncrypt(self, request):
-        """u200dThis API u200dis used to encrypt using PQC. It supports up to 4 KB of data. It is applicable for encryption of database passwords, RSA keys, or other sensitive information. You can also apply `DataKey` generated by API `GenerateDataKey` to encrypt or decrypt your local data.
+        """This API is used to encrypt using PQC. It supports up to 4 KB of data. It is applicable for encryption of database passwords, RSA keys, or other sensitive information. You can also apply `DataKey` generated by API `GenerateDataKey` to encrypt or decrypt your local data.
 
         :param request: Request instance for PostQuantumCryptoEncrypt.
         :type request: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoEncryptRequest`
@@ -1040,7 +1040,7 @@ class KmsClient(AbstractClient):
 
 
     def PostQuantumCryptoSign(self, request):
-        """This API is used to sign u200dusing PQC.
+        """This API is used to sign using PQC.
 
         :param request: Request instance for PostQuantumCryptoSign.
         :type request: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoSignRequest`
@@ -1063,7 +1063,7 @@ class KmsClient(AbstractClient):
 
 
     def PostQuantumCryptoVerify(self, request):
-        """This API is used to verify a signature u200dusing PQC.
+        """This API is used to verify a signature using PQC.
 
         :param request: Request instance for PostQuantumCryptoVerify.
         :type request: :class:`tencentcloud.kms.v20190118.models.PostQuantumCryptoVerifyRequest`
