@@ -150,6 +150,29 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateDisks(self, request):
+        """This API is used to create one or more cloud disks.
+
+        :param request: Request instance for CreateDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.CreateDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.CreateDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDisks", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDisksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateFirewallRules(self, request):
         """This API is used to add a firewall rule on an instance.
 
@@ -1039,7 +1062,7 @@ class LighthouseClient(AbstractClient):
 
 
     def DetachCcn(self, request):
-        """This API is used to unassociate a CCN instance.
+        """This API is used to disassociate with a CCN instance.
 
         :param request: Request instance for DetachCcn.
         :type request: :class:`tencentcloud.lighthouse.v20200324.models.DetachCcnRequest`
@@ -1251,6 +1274,34 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def IsolateDisks(self, request):
+        """This API is used to return one or more Lighthouse cloud disks.
+
+        You can only perform this operation on `UNATTACHED` disks.
+        After the successful call of the API, the cloud disk goes to the SHUTDOWN state.
+        Up to 20 instances are supported at one time.
+        This API is async. After the request is sent, a `RequestId` is returned. At this time, the operation is not completed yet. To check the result, you need to call  [DescribeDisks](https://intl.cloud.tencent.com/document/product/1207/66093?from_cn_redirect=1). If the latest operation status (LatestOperationState) of the disk is `SUCCESS`, the operation is successful.
+
+        :param request: Request instance for IsolateDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.IsolateDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.IsolateDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("IsolateDisks", params, headers=headers)
+            response = json.loads(body)
+            model = models.IsolateDisksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def IsolateInstances(self, request):
         """This API is used to return one or more Lighthouse instances.
         * Only `RUNNING` and `STOPPED` instances can be returned.
@@ -1566,6 +1617,59 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RenewDisks(self, request):
+        """This API is used to renew one or more Lighthouse cloud disks.
+
+        This operation can only be performed on data disks with the status of `ATTACHED`, `UNATTACHED` or `SHUTDOWN`.
+        Up to 50 cloud disks are supported at one time.
+        This API is async. After the request is sent, a `RequestId` is returned. At this time, the operation is not completed yet. To check the result, you need to call  [DescribeDisks](https://intl.cloud.tencent.com/document/product/1207/66093?from_cn_redirect=1). If the latest operation status (LatestOperationState) of the disk is `SUCCESS`, the operation is successful.
+
+        :param request: Request instance for RenewDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.RenewDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.RenewDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RenewDisks", params, headers=headers)
+            response = json.loads(body)
+            model = models.RenewDisksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def RenewInstances(self, request):
+        """This API is used to renew one or more Lighthouse instances.
+        * You can only perform this operation on instances whose status is `RUNNING`, `STOPPED` and `SHUTDOWN`.
+        * Batch operations are supported. Up to 100 instances are supported in each request.
+        * This API is async. After the request is sent successfully, a `RequestId` will be returned. At this time, the operation is not completed immediately. The result of the instance operation can be queried by calling the `DescribeInstances` API. If the latest operation status (LatestOperationState) of the instance is `SUCCESS`, the operation is successful.
+
+        :param request: Request instance for RenewInstances.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.RenewInstancesRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.RenewInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RenewInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.RenewInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ResetAttachCcn(self, request):
         """This API is used to apply for association again after a CCN instance association application expires.
 
