@@ -377,6 +377,9 @@ INVALIDPARAMETER_INPUTNUMLIMITEXCEEDED = 'InvalidParameter.InputNumLimitExceeded
 # Invalid background length and width.
 INVALIDPARAMETER_INVALIDBACKGROUDRESOLUTION = 'InvalidParameter.InvalidBackgroudResolution'
 
+# invalid BackupToUrl.
+INVALIDPARAMETER_INVALIDBACKUPTOURL = 'InvalidParameter.InvalidBackupToUrl'
+
 # Invalid output bitrate.
 INVALIDPARAMETER_INVALIDBITRATE = 'InvalidParameter.InvalidBitrate'
 
