@@ -44,6 +44,9 @@ INVALIDPARAMETER_ENDTIME = 'InvalidParameter.EndTime'
 # The quantity exceeds the limit.
 INVALIDPARAMETER_EXCEEDEDQUANTITYLIMIT = 'InvalidParameter.ExceededQuantityLimit'
 
+# 
+INVALIDPARAMETER_FRAMECAPTURETEMPLATES = 'InvalidParameter.FrameCaptureTemplates'
+
 # Invalid `Id`.
 INVALIDPARAMETER_ID = 'InvalidParameter.Id'
 
@@ -59,6 +62,12 @@ INVALIDPARAMETER_NAME = 'InvalidParameter.Name'
 # Not found.
 INVALIDPARAMETER_NOTFOUND = 'InvalidParameter.NotFound'
 
+# Callback key format error.
+INVALIDPARAMETER_NOTIFYKEY = 'InvalidParameter.NotifyKey'
+
+# Callback URL format error.
+INVALIDPARAMETER_NOTIFYURL = 'InvalidParameter.NotifyUrl'
+
 # Invalid `OutputGroups`.
 INVALIDPARAMETER_OUTPUTGROUPS = 'InvalidParameter.OutputGroups'
 
