@@ -18,6 +18,51 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class AliasValueConf(AbstractModel):
+    """Alias-value configuration information.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Alias: Alias.
+        :type Alias: str
+        :param _Value: Value.
+        :type Value: str
+        """
+        self._Alias = None
+        self._Value = None
+
+    @property
+    def Alias(self):
+        return self._Alias
+
+    @Alias.setter
+    def Alias(self, Alias):
+        self._Alias = Alias
+
+    @property
+    def Value(self):
+        return self._Value
+
+    @Value.setter
+    def Value(self, Value):
+        self._Value = Value
+
+
+    def _deserialize(self, params):
+        self._Alias = params.get("Alias")
+        self._Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class BindNewLVBDomainWithChannelRequest(AbstractModel):
     """BindNewLVBDomainWithChannel request structure.
 
@@ -72,7 +117,7 @@ class BindNewLVBDomainWithChannelResponse(AbstractModel):
         r"""
         :param _LVBDomain: The LVB domain name bound successfully
         :type LVBDomain: str
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._LVBDomain = None
@@ -273,6 +318,56 @@ Note: this field may return `null`, indicating that no valid value was found.
         
 
 
+class ConfigAliasesInfo(AbstractModel):
+    """Parameter configuration.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ParamName: parameter name.
+        :type ParamName: str
+        :param _AliasValueList: Alias-value configuration.
+        :type AliasValueList: list of AliasValueConf
+        """
+        self._ParamName = None
+        self._AliasValueList = None
+
+    @property
+    def ParamName(self):
+        return self._ParamName
+
+    @ParamName.setter
+    def ParamName(self, ParamName):
+        self._ParamName = ParamName
+
+    @property
+    def AliasValueList(self):
+        return self._AliasValueList
+
+    @AliasValueList.setter
+    def AliasValueList(self, AliasValueList):
+        self._AliasValueList = AliasValueList
+
+
+    def _deserialize(self, params):
+        self._ParamName = params.get("ParamName")
+        if params.get("AliasValueList") is not None:
+            self._AliasValueList = []
+            for item in params.get("AliasValueList"):
+                obj = AliasValueConf()
+                obj._deserialize(item)
+                self._AliasValueList.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class CreateStreamPackageChannelEndpointRequest(AbstractModel):
     """CreateStreamPackageChannelEndpoint request structure.
 
@@ -286,10 +381,22 @@ class CreateStreamPackageChannelEndpointRequest(AbstractModel):
         :type Name: str
         :param _AuthInfo: Authentication information
         :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
+        :param _Protocol: Endpoint protocol type, supports HLS, DASH, CMAF (only HLS type input can create CMAF Endpoint).
+        :type Protocol: str
+        :param _Manifest: Mainifest name, default is main.
+        :type Manifest: str
+        :param _TimeShiftEnable: Whether to turn on the TimeShift function, true: on, false: off, the default is off.
+        :type TimeShiftEnable: bool
+        :param _TimeShiftDuration: The number of days to look back in TimeShift, up to 30 days is supported.
+        :type TimeShiftDuration: int
         """
         self._Id = None
         self._Name = None
         self._AuthInfo = None
+        self._Protocol = None
+        self._Manifest = None
+        self._TimeShiftEnable = None
+        self._TimeShiftDuration = None
 
     @property
     def Id(self):
@@ -315,6 +422,38 @@ class CreateStreamPackageChannelEndpointRequest(AbstractModel):
     def AuthInfo(self, AuthInfo):
         self._AuthInfo = AuthInfo
 
+    @property
+    def Protocol(self):
+        return self._Protocol
+
+    @Protocol.setter
+    def Protocol(self, Protocol):
+        self._Protocol = Protocol
+
+    @property
+    def Manifest(self):
+        return self._Manifest
+
+    @Manifest.setter
+    def Manifest(self, Manifest):
+        self._Manifest = Manifest
+
+    @property
+    def TimeShiftEnable(self):
+        return self._TimeShiftEnable
+
+    @TimeShiftEnable.setter
+    def TimeShiftEnable(self, TimeShiftEnable):
+        self._TimeShiftEnable = TimeShiftEnable
+
+    @property
+    def TimeShiftDuration(self):
+        return self._TimeShiftDuration
+
+    @TimeShiftDuration.setter
+    def TimeShiftDuration(self, TimeShiftDuration):
+        self._TimeShiftDuration = TimeShiftDuration
+
 
     def _deserialize(self, params):
         self._Id = params.get("Id")
@@ -322,6 +461,10 @@ class CreateStreamPackageChannelEndpointRequest(AbstractModel):
         if params.get("AuthInfo") is not None:
             self._AuthInfo = EndpointAuthInfo()
             self._AuthInfo._deserialize(params.get("AuthInfo"))
+        self._Protocol = params.get("Protocol")
+        self._Manifest = params.get("Manifest")
+        self._TimeShiftEnable = params.get("TimeShiftEnable")
+        self._TimeShiftDuration = params.get("TimeShiftDuration")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -341,7 +484,7 @@ class CreateStreamPackageChannelEndpointResponse(AbstractModel):
         r"""
         :param _Info: Information of the created channel endpoint
         :type Info: :class:`tencentcloud.mdp.v20200527.models.EndpointInfo`
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Info = None
@@ -439,7 +582,7 @@ class CreateStreamPackageChannelResponse(AbstractModel):
         r"""
         :param _Info: Channel information
         :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Info = None
@@ -595,7 +738,7 @@ class CreateStreamPackageHarvestJobResponse(AbstractModel):
         r"""
         :param _Info: HarvestJob information.
         :type Info: :class:`tencentcloud.mdp.v20200527.models.HarvestJobResp`
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Info = None
@@ -677,7 +820,7 @@ class DeleteStreamPackageChannelEndpointsResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
@@ -739,7 +882,7 @@ class DeleteStreamPackageChannelsResponse(AbstractModel):
         :type SuccessInfos: list of ChannelInfo
         :param _FailInfos: List of the information of the channels that failed to be deleted
         :type FailInfos: list of ChannelInfo
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._SuccessInfos = None
@@ -827,7 +970,7 @@ class DeleteStreamPackageHarvestJobResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
@@ -885,7 +1028,7 @@ class DeleteStreamPackageHarvestJobsResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
@@ -945,7 +1088,7 @@ class DescribeStreamPackageChannelResponse(AbstractModel):
         r"""
         :param _Info: Channel information
         :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Info = None
@@ -1038,7 +1181,7 @@ Note: this field may return `null`, indicating that no valid value was found.
         :type TotalNum: int
         :param _TotalPage: Total number of pages
         :type TotalPage: int
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Infos = None
@@ -1153,7 +1296,7 @@ class DescribeStreamPackageHarvestJobResponse(AbstractModel):
         r"""
         :param _Info: HarvestJob information.
         :type Info: :class:`tencentcloud.mdp.v20200527.models.HarvestJobResp`
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Info = None
@@ -1255,7 +1398,7 @@ class DescribeStreamPackageHarvestJobsResponse(AbstractModel):
         :type PageSize: int
         :param _TotalNum: TotalNum
         :type TotalNum: int
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Infos = None
@@ -1391,10 +1534,35 @@ class EndpointInfo(AbstractModel):
         :type Url: str
         :param _AuthInfo: Endpoint authentication information.
         :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
+        :param _Protocol: Endpoint protocol.
+        :type Protocol: str
+        :param _Manifest: Manifest name, default is main.
+        :type Manifest: str
+        :param _TimeShiftEnable: Whether to turn on the time shift function, true: on, false: off, the default is off.
+        :type TimeShiftEnable: bool
+        :param _TimeShiftDuration: The number of days in the time shift window, up to 30 days. Valid when TimeShiftEnable is turned on.
+        :type TimeShiftDuration: int
+        :param _SSAIEnable: Advertising insertion function switch.
+        :type SSAIEnable: bool
+        :param _SSAIInfo: Ad insertion function configuration information.
+        :type SSAIInfo: :class:`tencentcloud.mdp.v20200527.models.SSAIConf`
+        :param _CustomUrlParamIndex: The customer-defined url parameter is inserted into the subscript at the specified position of the Endpoint url. The optional range of the subscript is: [0,3].
+        :type CustomUrlParamIndex: int
+        :param _CustomUrlParam: Customer-defined url parameters are inserted into the specified position of the Endpoint url based on the CustomUrlParamIndex.
+The parameters can only contain digits, letters, underscores (_), and hyphens (-), with a length of 1 to 64 chars.
+        :type CustomUrlParam: str
         """
         self._Name = None
         self._Url = None
         self._AuthInfo = None
+        self._Protocol = None
+        self._Manifest = None
+        self._TimeShiftEnable = None
+        self._TimeShiftDuration = None
+        self._SSAIEnable = None
+        self._SSAIInfo = None
+        self._CustomUrlParamIndex = None
+        self._CustomUrlParam = None
 
     @property
     def Name(self):
@@ -1420,6 +1588,70 @@ class EndpointInfo(AbstractModel):
     def AuthInfo(self, AuthInfo):
         self._AuthInfo = AuthInfo
 
+    @property
+    def Protocol(self):
+        return self._Protocol
+
+    @Protocol.setter
+    def Protocol(self, Protocol):
+        self._Protocol = Protocol
+
+    @property
+    def Manifest(self):
+        return self._Manifest
+
+    @Manifest.setter
+    def Manifest(self, Manifest):
+        self._Manifest = Manifest
+
+    @property
+    def TimeShiftEnable(self):
+        return self._TimeShiftEnable
+
+    @TimeShiftEnable.setter
+    def TimeShiftEnable(self, TimeShiftEnable):
+        self._TimeShiftEnable = TimeShiftEnable
+
+    @property
+    def TimeShiftDuration(self):
+        return self._TimeShiftDuration
+
+    @TimeShiftDuration.setter
+    def TimeShiftDuration(self, TimeShiftDuration):
+        self._TimeShiftDuration = TimeShiftDuration
+
+    @property
+    def SSAIEnable(self):
+        return self._SSAIEnable
+
+    @SSAIEnable.setter
+    def SSAIEnable(self, SSAIEnable):
+        self._SSAIEnable = SSAIEnable
+
+    @property
+    def SSAIInfo(self):
+        return self._SSAIInfo
+
+    @SSAIInfo.setter
+    def SSAIInfo(self, SSAIInfo):
+        self._SSAIInfo = SSAIInfo
+
+    @property
+    def CustomUrlParamIndex(self):
+        return self._CustomUrlParamIndex
+
+    @CustomUrlParamIndex.setter
+    def CustomUrlParamIndex(self, CustomUrlParamIndex):
+        self._CustomUrlParamIndex = CustomUrlParamIndex
+
+    @property
+    def CustomUrlParam(self):
+        return self._CustomUrlParam
+
+    @CustomUrlParam.setter
+    def CustomUrlParam(self, CustomUrlParam):
+        self._CustomUrlParam = CustomUrlParam
+
 
     def _deserialize(self, params):
         self._Name = params.get("Name")
@@ -1427,6 +1659,16 @@ class EndpointInfo(AbstractModel):
         if params.get("AuthInfo") is not None:
             self._AuthInfo = EndpointAuthInfo()
             self._AuthInfo._deserialize(params.get("AuthInfo"))
+        self._Protocol = params.get("Protocol")
+        self._Manifest = params.get("Manifest")
+        self._TimeShiftEnable = params.get("TimeShiftEnable")
+        self._TimeShiftDuration = params.get("TimeShiftDuration")
+        self._SSAIEnable = params.get("SSAIEnable")
+        if params.get("SSAIInfo") is not None:
+            self._SSAIInfo = SSAIConf()
+            self._SSAIInfo._deserialize(params.get("SSAIInfo"))
+        self._CustomUrlParamIndex = params.get("CustomUrlParamIndex")
+        self._CustomUrlParam = params.get("CustomUrlParam")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -1724,11 +1966,34 @@ class ModifyStreamPackageChannelEndpointRequest(AbstractModel):
         :type Name: str
         :param _AuthInfo: New channel authentication information
         :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
+        :param _Protocol: Endpoint protocol.
+        :type Protocol: str
+        :param _TimeShiftEnable: Whether to turn on the time shift function, true: on, false: off, the default is off.
+        :type TimeShiftEnable: bool
+        :param _TimeShiftDuration: The number of days in the time shift window, up to 30 days. Valid when TimeShiftEnable is turned on.
+        :type TimeShiftDuration: int
+        :param _SSAIEnable: Advertising insertion function switch.
+        :type SSAIEnable: bool
+        :param _SSAIInfo: Ad insertion function configuration information. Valid when SSAIEnable is turned on.
+        :type SSAIInfo: :class:`tencentcloud.mdp.v20200527.models.SSAIConf`
+        :param _CustomUrlParamIndex: The customer-defined url parameter is inserted into the subscript at the specified position of the Endpoint url. 
+Calculation starts from the first '/' in the url path, and the subscript starts from 0, the optional range of the subscript is: [0,3].
+        :type CustomUrlParamIndex: int
+        :param _CustomUrlParam: Customer-defined url parameters are inserted into the specified position of the Endpoint url based on the CustomUrlParamIndex.
+The parameters can only contain digits, letters, underscores (_), and hyphens (-), with a length of 1 to 64 chars.
+        :type CustomUrlParam: str
         """
         self._Id = None
         self._Url = None
         self._Name = None
         self._AuthInfo = None
+        self._Protocol = None
+        self._TimeShiftEnable = None
+        self._TimeShiftDuration = None
+        self._SSAIEnable = None
+        self._SSAIInfo = None
+        self._CustomUrlParamIndex = None
+        self._CustomUrlParam = None
 
     @property
     def Id(self):
@@ -1762,6 +2027,62 @@ class ModifyStreamPackageChannelEndpointRequest(AbstractModel):
     def AuthInfo(self, AuthInfo):
         self._AuthInfo = AuthInfo
 
+    @property
+    def Protocol(self):
+        return self._Protocol
+
+    @Protocol.setter
+    def Protocol(self, Protocol):
+        self._Protocol = Protocol
+
+    @property
+    def TimeShiftEnable(self):
+        return self._TimeShiftEnable
+
+    @TimeShiftEnable.setter
+    def TimeShiftEnable(self, TimeShiftEnable):
+        self._TimeShiftEnable = TimeShiftEnable
+
+    @property
+    def TimeShiftDuration(self):
+        return self._TimeShiftDuration
+
+    @TimeShiftDuration.setter
+    def TimeShiftDuration(self, TimeShiftDuration):
+        self._TimeShiftDuration = TimeShiftDuration
+
+    @property
+    def SSAIEnable(self):
+        return self._SSAIEnable
+
+    @SSAIEnable.setter
+    def SSAIEnable(self, SSAIEnable):
+        self._SSAIEnable = SSAIEnable
+
+    @property
+    def SSAIInfo(self):
+        return self._SSAIInfo
+
+    @SSAIInfo.setter
+    def SSAIInfo(self, SSAIInfo):
+        self._SSAIInfo = SSAIInfo
+
+    @property
+    def CustomUrlParamIndex(self):
+        return self._CustomUrlParamIndex
+
+    @CustomUrlParamIndex.setter
+    def CustomUrlParamIndex(self, CustomUrlParamIndex):
+        self._CustomUrlParamIndex = CustomUrlParamIndex
+
+    @property
+    def CustomUrlParam(self):
+        return self._CustomUrlParam
+
+    @CustomUrlParam.setter
+    def CustomUrlParam(self, CustomUrlParam):
+        self._CustomUrlParam = CustomUrlParam
+
 
     def _deserialize(self, params):
         self._Id = params.get("Id")
@@ -1770,6 +2091,15 @@ class ModifyStreamPackageChannelEndpointRequest(AbstractModel):
         if params.get("AuthInfo") is not None:
             self._AuthInfo = EndpointAuthInfo()
             self._AuthInfo._deserialize(params.get("AuthInfo"))
+        self._Protocol = params.get("Protocol")
+        self._TimeShiftEnable = params.get("TimeShiftEnable")
+        self._TimeShiftDuration = params.get("TimeShiftDuration")
+        self._SSAIEnable = params.get("SSAIEnable")
+        if params.get("SSAIInfo") is not None:
+            self._SSAIInfo = SSAIConf()
+            self._SSAIInfo._deserialize(params.get("SSAIInfo"))
+        self._CustomUrlParamIndex = params.get("CustomUrlParamIndex")
+        self._CustomUrlParam = params.get("CustomUrlParam")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -1787,7 +2117,7 @@ class ModifyStreamPackageChannelEndpointResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
@@ -1873,7 +2203,7 @@ class ModifyStreamPackageChannelInputAuthInfoResponse(AbstractModel):
         r"""
         :param _AuthInfo: Channel input authentication information
         :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._AuthInfo = None
@@ -1981,7 +2311,7 @@ class ModifyStreamPackageChannelResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
@@ -2055,6 +2385,154 @@ Note: this field may return null, indicating that no valid values can be obtaine
         
 
 
+class SSAIConf(AbstractModel):
+    """SSAI ad insertion configuration.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _AdsUrl: Advertising Decision Server URL (ADS).
+        :type AdsUrl: str
+        :param _ConfigAliases: Parameter configuration.
+        :type ConfigAliases: list of ConfigAliasesInfo
+        :param _SlateAd: Default advertising url.
+        :type SlateAd: str
+        :param _Threshold: Maximum unfilled duration, unit: seconds.
+        :type Threshold: int
+        :param _DashMPDLocation: Whether to enable mpd location, true corresponds to enable, false corresponds to disable.
+        :type DashMPDLocation: bool
+        :param _AdMarkerPassthrough: Whether to enable transparent transmission of advertising tags.
+        :type AdMarkerPassthrough: bool
+        :param _SCTE35AdType: How to process tags in advertisements, optional values: [1,2] 
+1: Process all SCTE-35 type tags - all (default) 
+2: SCTE-35enhanced, parse some types.
+        :type SCTE35AdType: int
+        :param _AdTriggers: The type of tag that is regarded as an advertisement, optional values: [1,8]
+1. Splice insert 
+2. Provider advertisement 
+3. Distributor advertisement 
+4. Provider placement opportunity 
+5. Distributor placement opportunity 
+6. Break 
+7. Provider overlay placement opportunity 
+8. Distributor overlay placement opportunity.
+        :type AdTriggers: list of int non-negative
+        :param _DeliveryRestrictions: The type of distribution restriction that is considered an advertisement, optional values: [1,4]
+1:None 
+2:Restricted (default) 
+3:Unrestricted 
+4.Both.
+        :type DeliveryRestrictions: int
+        """
+        self._AdsUrl = None
+        self._ConfigAliases = None
+        self._SlateAd = None
+        self._Threshold = None
+        self._DashMPDLocation = None
+        self._AdMarkerPassthrough = None
+        self._SCTE35AdType = None
+        self._AdTriggers = None
+        self._DeliveryRestrictions = None
+
+    @property
+    def AdsUrl(self):
+        return self._AdsUrl
+
+    @AdsUrl.setter
+    def AdsUrl(self, AdsUrl):
+        self._AdsUrl = AdsUrl
+
+    @property
+    def ConfigAliases(self):
+        return self._ConfigAliases
+
+    @ConfigAliases.setter
+    def ConfigAliases(self, ConfigAliases):
+        self._ConfigAliases = ConfigAliases
+
+    @property
+    def SlateAd(self):
+        return self._SlateAd
+
+    @SlateAd.setter
+    def SlateAd(self, SlateAd):
+        self._SlateAd = SlateAd
+
+    @property
+    def Threshold(self):
+        return self._Threshold
+
+    @Threshold.setter
+    def Threshold(self, Threshold):
+        self._Threshold = Threshold
+
+    @property
+    def DashMPDLocation(self):
+        return self._DashMPDLocation
+
+    @DashMPDLocation.setter
+    def DashMPDLocation(self, DashMPDLocation):
+        self._DashMPDLocation = DashMPDLocation
+
+    @property
+    def AdMarkerPassthrough(self):
+        return self._AdMarkerPassthrough
+
+    @AdMarkerPassthrough.setter
+    def AdMarkerPassthrough(self, AdMarkerPassthrough):
+        self._AdMarkerPassthrough = AdMarkerPassthrough
+
+    @property
+    def SCTE35AdType(self):
+        return self._SCTE35AdType
+
+    @SCTE35AdType.setter
+    def SCTE35AdType(self, SCTE35AdType):
+        self._SCTE35AdType = SCTE35AdType
+
+    @property
+    def AdTriggers(self):
+        return self._AdTriggers
+
+    @AdTriggers.setter
+    def AdTriggers(self, AdTriggers):
+        self._AdTriggers = AdTriggers
+
+    @property
+    def DeliveryRestrictions(self):
+        return self._DeliveryRestrictions
+
+    @DeliveryRestrictions.setter
+    def DeliveryRestrictions(self, DeliveryRestrictions):
+        self._DeliveryRestrictions = DeliveryRestrictions
+
+
+    def _deserialize(self, params):
+        self._AdsUrl = params.get("AdsUrl")
+        if params.get("ConfigAliases") is not None:
+            self._ConfigAliases = []
+            for item in params.get("ConfigAliases"):
+                obj = ConfigAliasesInfo()
+                obj._deserialize(item)
+                self._ConfigAliases.append(obj)
+        self._SlateAd = params.get("SlateAd")
+        self._Threshold = params.get("Threshold")
+        self._DashMPDLocation = params.get("DashMPDLocation")
+        self._AdMarkerPassthrough = params.get("AdMarkerPassthrough")
+        self._SCTE35AdType = params.get("SCTE35AdType")
+        self._AdTriggers = params.get("AdTriggers")
+        self._DeliveryRestrictions = params.get("DeliveryRestrictions")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class UnbindCdnDomainWithChannelRequest(AbstractModel):
     """UnbindCdnDomainWithChannel request structure.
 
@@ -2107,7 +2585,7 @@ class UnbindCdnDomainWithChannelResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
