@@ -389,7 +389,7 @@ class CreatePrivateDNSAccountResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
@@ -521,7 +521,7 @@ class CreatePrivateZoneRecordResponse(AbstractModel):
         r"""
         :param _RecordId: Record ID
         :type RecordId: str
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RecordId = None
@@ -697,7 +697,7 @@ class CreatePrivateZoneResponse(AbstractModel):
         :type ZoneId: str
         :param _Domain: Private domain
         :type Domain: str
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._ZoneId = None
@@ -780,6 +780,88 @@ class DatePoint(AbstractModel):
         
 
 
+class DeletePrivateZoneRecordRequest(AbstractModel):
+    """DeletePrivateZoneRecord request structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ZoneId: Private domain ID
+        :type ZoneId: str
+        :param _RecordId: Record ID
+        :type RecordId: str
+        :param _RecordIdSet: Array of record IDs. `RecordId` takes precedence.
+        :type RecordIdSet: list of str
+        """
+        self._ZoneId = None
+        self._RecordId = None
+        self._RecordIdSet = None
+
+    @property
+    def ZoneId(self):
+        return self._ZoneId
+
+    @ZoneId.setter
+    def ZoneId(self, ZoneId):
+        self._ZoneId = ZoneId
+
+    @property
+    def RecordId(self):
+        return self._RecordId
+
+    @RecordId.setter
+    def RecordId(self, RecordId):
+        self._RecordId = RecordId
+
+    @property
+    def RecordIdSet(self):
+        return self._RecordIdSet
+
+    @RecordIdSet.setter
+    def RecordIdSet(self, RecordIdSet):
+        self._RecordIdSet = RecordIdSet
+
+
+    def _deserialize(self, params):
+        self._ZoneId = params.get("ZoneId")
+        self._RecordId = params.get("RecordId")
+        self._RecordIdSet = params.get("RecordIdSet")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DeletePrivateZoneRecordResponse(AbstractModel):
+    """DeletePrivateZoneRecord response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self._RequestId = None
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._RequestId = params.get("RequestId")
+
+
 class DescribeAccountVpcListRequest(AbstractModel):
     """DescribeAccountVpcList request structure.
 
@@ -865,7 +947,7 @@ class DescribeAccountVpcListResponse(AbstractModel):
         :type TotalCount: int
         :param _VpcSet: VPC list
         :type VpcSet: list of AccountVpcInfoOut
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._TotalCount = None
@@ -1003,7 +1085,7 @@ class DescribeAuditLogResponse(AbstractModel):
         r"""
         :param _Data: List of operation logs
         :type Data: list of AuditLog
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Data = None
@@ -1057,7 +1139,7 @@ class DescribeDashboardResponse(AbstractModel):
         :type RequestTotalCount: int
         :param _FlowUsage: Traffic package usage
         :type FlowUsage: list of FlowUsage
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._ZoneTotal = None
@@ -1193,7 +1275,7 @@ class DescribePrivateDNSAccountListResponse(AbstractModel):
         :type TotalCount: int
         :param _AccountSet: List of Private DNS accounts
         :type AccountSet: list of PrivateDNSAccount
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._TotalCount = None
@@ -1236,6 +1318,250 @@ class DescribePrivateDNSAccountListResponse(AbstractModel):
         self._RequestId = params.get("RequestId")
 
 
+class DescribePrivateZoneListRequest(AbstractModel):
+    """DescribePrivateZoneList request structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Offset: Pagination offset, starting from 0
+        :type Offset: int
+        :param _Limit: Number of entries per page. Maximum value: 100. Default value: 20
+        :type Limit: int
+        :param _Filters: Filter parameter
+        :type Filters: list of Filter
+        """
+        self._Offset = None
+        self._Limit = None
+        self._Filters = None
+
+    @property
+    def Offset(self):
+        return self._Offset
+
+    @Offset.setter
+    def Offset(self, Offset):
+        self._Offset = Offset
+
+    @property
+    def Limit(self):
+        return self._Limit
+
+    @Limit.setter
+    def Limit(self, Limit):
+        self._Limit = Limit
+
+    @property
+    def Filters(self):
+        return self._Filters
+
+    @Filters.setter
+    def Filters(self, Filters):
+        self._Filters = Filters
+
+
+    def _deserialize(self, params):
+        self._Offset = params.get("Offset")
+        self._Limit = params.get("Limit")
+        if params.get("Filters") is not None:
+            self._Filters = []
+            for item in params.get("Filters"):
+                obj = Filter()
+                obj._deserialize(item)
+                self._Filters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribePrivateZoneListResponse(AbstractModel):
+    """DescribePrivateZoneList response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _TotalCount: Number of private domains
+        :type TotalCount: int
+        :param _PrivateZoneSet: List of private domains
+        :type PrivateZoneSet: list of PrivateZone
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self._TotalCount = None
+        self._PrivateZoneSet = None
+        self._RequestId = None
+
+    @property
+    def TotalCount(self):
+        return self._TotalCount
+
+    @TotalCount.setter
+    def TotalCount(self, TotalCount):
+        self._TotalCount = TotalCount
+
+    @property
+    def PrivateZoneSet(self):
+        return self._PrivateZoneSet
+
+    @PrivateZoneSet.setter
+    def PrivateZoneSet(self, PrivateZoneSet):
+        self._PrivateZoneSet = PrivateZoneSet
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._TotalCount = params.get("TotalCount")
+        if params.get("PrivateZoneSet") is not None:
+            self._PrivateZoneSet = []
+            for item in params.get("PrivateZoneSet"):
+                obj = PrivateZone()
+                obj._deserialize(item)
+                self._PrivateZoneSet.append(obj)
+        self._RequestId = params.get("RequestId")
+
+
+class DescribePrivateZoneRecordListRequest(AbstractModel):
+    """DescribePrivateZoneRecordList request structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ZoneId: Private domain ID: zone-xxxxxx
+        :type ZoneId: str
+        :param _Filters: Filter parameter
+        :type Filters: list of Filter
+        :param _Offset: Pagination offset, starting from 0
+        :type Offset: int
+        :param _Limit: Number of entries per page. Maximum value: 100. Default value: 20
+        :type Limit: int
+        """
+        self._ZoneId = None
+        self._Filters = None
+        self._Offset = None
+        self._Limit = None
+
+    @property
+    def ZoneId(self):
+        return self._ZoneId
+
+    @ZoneId.setter
+    def ZoneId(self, ZoneId):
+        self._ZoneId = ZoneId
+
+    @property
+    def Filters(self):
+        return self._Filters
+
+    @Filters.setter
+    def Filters(self, Filters):
+        self._Filters = Filters
+
+    @property
+    def Offset(self):
+        return self._Offset
+
+    @Offset.setter
+    def Offset(self, Offset):
+        self._Offset = Offset
+
+    @property
+    def Limit(self):
+        return self._Limit
+
+    @Limit.setter
+    def Limit(self, Limit):
+        self._Limit = Limit
+
+
+    def _deserialize(self, params):
+        self._ZoneId = params.get("ZoneId")
+        if params.get("Filters") is not None:
+            self._Filters = []
+            for item in params.get("Filters"):
+                obj = Filter()
+                obj._deserialize(item)
+                self._Filters.append(obj)
+        self._Offset = params.get("Offset")
+        self._Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribePrivateZoneRecordListResponse(AbstractModel):
+    """DescribePrivateZoneRecordList response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _TotalCount: Number of DNS records
+        :type TotalCount: int
+        :param _RecordSet: List of DNS records
+        :type RecordSet: list of PrivateZoneRecord
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self._TotalCount = None
+        self._RecordSet = None
+        self._RequestId = None
+
+    @property
+    def TotalCount(self):
+        return self._TotalCount
+
+    @TotalCount.setter
+    def TotalCount(self, TotalCount):
+        self._TotalCount = TotalCount
+
+    @property
+    def RecordSet(self):
+        return self._RecordSet
+
+    @RecordSet.setter
+    def RecordSet(self, RecordSet):
+        self._RecordSet = RecordSet
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._TotalCount = params.get("TotalCount")
+        if params.get("RecordSet") is not None:
+            self._RecordSet = []
+            for item in params.get("RecordSet"):
+                obj = PrivateZoneRecord()
+                obj._deserialize(item)
+                self._RecordSet.append(obj)
+        self._RequestId = params.get("RequestId")
+
+
 class DescribePrivateZoneServiceRequest(AbstractModel):
     """DescribePrivateZoneService request structure.
 
@@ -1251,7 +1577,7 @@ class DescribePrivateZoneServiceResponse(AbstractModel):
         r"""
         :param _ServiceStatus: Private DNS service activation status. Valid values: ENABLED, DISABLED
         :type ServiceStatus: str
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._ServiceStatus = None
@@ -1294,7 +1620,7 @@ class DescribeQuotaUsageResponse(AbstractModel):
         r"""
         :param _TldQuota: TLD quota usage
         :type TldQuota: :class:`tencentcloud.privatedns.v20201028.models.TldQuota`
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._TldQuota = None
@@ -1397,7 +1723,7 @@ class DescribeRequestDataResponse(AbstractModel):
         :type Data: list of MetricData
         :param _Interval: Request volume unit time. Valid values: Day, Hour
         :type Interval: str
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._Data = None
@@ -1741,7 +2067,7 @@ class ModifyPrivateZoneRecordResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
@@ -1835,7 +2161,7 @@ class ModifyPrivateZoneResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._RequestId = None
@@ -1933,7 +2259,7 @@ class ModifyPrivateZoneVpcResponse(AbstractModel):
         :type VpcSet: list of VpcInfo
         :param _AccountVpcSet: List of authorized accounts' VPCs associated with the private domain
         :type AccountVpcSet: list of AccountVpcInfoOutput
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._ZoneId = None
@@ -2061,7 +2387,7 @@ class ModifyRecordsStatusResponse(AbstractModel):
         :type RecordIds: list of int
         :param _Status: `enabled`: Enabled; `disabled`: Disabled.
         :type Status: str
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._ZoneId = None
@@ -2166,6 +2492,356 @@ class PrivateDNSAccount(AbstractModel):
         
 
 
+class PrivateZone(AbstractModel):
+    """Private domain information
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ZoneId: Private domain ID: zone-xxxxxxxx
+        :type ZoneId: str
+        :param _OwnerUin: Domain name owner UIN
+        :type OwnerUin: int
+        :param _Domain: Private domain
+        :type Domain: str
+        :param _CreatedOn: Creation time
+        :type CreatedOn: str
+        :param _UpdatedOn: Modification time
+        :type UpdatedOn: str
+        :param _RecordCount: Number of results
+        :type RecordCount: int
+        :param _Remark: Remarks
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type Remark: str
+        :param _VpcSet: List of bound VPCs
+        :type VpcSet: list of VpcInfo
+        :param _Status: Private domain status. Valid values: ENABLED (DNS enabled); SUSPEND (DNS paused); FROZEN (locked)
+        :type Status: str
+        :param _DnsForwardStatus: Subdomain recursive DNS status. Valid values: ENABLED, DISABLED
+        :type DnsForwardStatus: str
+        :param _Tags: Set of tag key-value pairs
+        :type Tags: list of TagInfo
+        :param _AccountVpcSet: List of authorized accounts' VPCs associated with the private domain
+Note: this field may return `null`, indicating that no valid values can be obtained.
+        :type AccountVpcSet: list of AccountVpcInfoOutput
+        """
+        self._ZoneId = None
+        self._OwnerUin = None
+        self._Domain = None
+        self._CreatedOn = None
+        self._UpdatedOn = None
+        self._RecordCount = None
+        self._Remark = None
+        self._VpcSet = None
+        self._Status = None
+        self._DnsForwardStatus = None
+        self._Tags = None
+        self._AccountVpcSet = None
+
+    @property
+    def ZoneId(self):
+        return self._ZoneId
+
+    @ZoneId.setter
+    def ZoneId(self, ZoneId):
+        self._ZoneId = ZoneId
+
+    @property
+    def OwnerUin(self):
+        return self._OwnerUin
+
+    @OwnerUin.setter
+    def OwnerUin(self, OwnerUin):
+        self._OwnerUin = OwnerUin
+
+    @property
+    def Domain(self):
+        return self._Domain
+
+    @Domain.setter
+    def Domain(self, Domain):
+        self._Domain = Domain
+
+    @property
+    def CreatedOn(self):
+        return self._CreatedOn
+
+    @CreatedOn.setter
+    def CreatedOn(self, CreatedOn):
+        self._CreatedOn = CreatedOn
+
+    @property
+    def UpdatedOn(self):
+        return self._UpdatedOn
+
+    @UpdatedOn.setter
+    def UpdatedOn(self, UpdatedOn):
+        self._UpdatedOn = UpdatedOn
+
+    @property
+    def RecordCount(self):
+        return self._RecordCount
+
+    @RecordCount.setter
+    def RecordCount(self, RecordCount):
+        self._RecordCount = RecordCount
+
+    @property
+    def Remark(self):
+        return self._Remark
+
+    @Remark.setter
+    def Remark(self, Remark):
+        self._Remark = Remark
+
+    @property
+    def VpcSet(self):
+        return self._VpcSet
+
+    @VpcSet.setter
+    def VpcSet(self, VpcSet):
+        self._VpcSet = VpcSet
+
+    @property
+    def Status(self):
+        return self._Status
+
+    @Status.setter
+    def Status(self, Status):
+        self._Status = Status
+
+    @property
+    def DnsForwardStatus(self):
+        return self._DnsForwardStatus
+
+    @DnsForwardStatus.setter
+    def DnsForwardStatus(self, DnsForwardStatus):
+        self._DnsForwardStatus = DnsForwardStatus
+
+    @property
+    def Tags(self):
+        return self._Tags
+
+    @Tags.setter
+    def Tags(self, Tags):
+        self._Tags = Tags
+
+    @property
+    def AccountVpcSet(self):
+        return self._AccountVpcSet
+
+    @AccountVpcSet.setter
+    def AccountVpcSet(self, AccountVpcSet):
+        self._AccountVpcSet = AccountVpcSet
+
+
+    def _deserialize(self, params):
+        self._ZoneId = params.get("ZoneId")
+        self._OwnerUin = params.get("OwnerUin")
+        self._Domain = params.get("Domain")
+        self._CreatedOn = params.get("CreatedOn")
+        self._UpdatedOn = params.get("UpdatedOn")
+        self._RecordCount = params.get("RecordCount")
+        self._Remark = params.get("Remark")
+        if params.get("VpcSet") is not None:
+            self._VpcSet = []
+            for item in params.get("VpcSet"):
+                obj = VpcInfo()
+                obj._deserialize(item)
+                self._VpcSet.append(obj)
+        self._Status = params.get("Status")
+        self._DnsForwardStatus = params.get("DnsForwardStatus")
+        if params.get("Tags") is not None:
+            self._Tags = []
+            for item in params.get("Tags"):
+                obj = TagInfo()
+                obj._deserialize(item)
+                self._Tags.append(obj)
+        if params.get("AccountVpcSet") is not None:
+            self._AccountVpcSet = []
+            for item in params.get("AccountVpcSet"):
+                obj = AccountVpcInfoOutput()
+                obj._deserialize(item)
+                self._AccountVpcSet.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class PrivateZoneRecord(AbstractModel):
+    """Private domain information
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _RecordId: Record ID
+        :type RecordId: str
+        :param _ZoneId: Private domain ID: zone-xxxxxxxx
+        :type ZoneId: str
+        :param _SubDomain: Subdomain
+        :type SubDomain: str
+        :param _RecordType: Record type. Valid values: "A", "AAAA", "CNAME", "MX", "TXT", "PTR"
+        :type RecordType: str
+        :param _RecordValue: Record value
+        :type RecordValue: str
+        :param _TTL: Record cache time. The smaller the value, the faster the record will take effect. Value range: 1–86400s. Default value: 600
+        :type TTL: int
+        :param _MX: MX priority, which is required when the record type is MX. Valid values: 5, 10, 15, 20, 30, 40, 50
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type MX: int
+        :param _Status: Record status: ENABLED
+        :type Status: str
+        :param _Weight: Record weight. Value range: 1–100
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type Weight: int
+        :param _CreatedOn: Record creation time
+        :type CreatedOn: str
+        :param _UpdatedOn: Record update time
+        :type UpdatedOn: str
+        :param _Extra: Additional information
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type Extra: str
+        """
+        self._RecordId = None
+        self._ZoneId = None
+        self._SubDomain = None
+        self._RecordType = None
+        self._RecordValue = None
+        self._TTL = None
+        self._MX = None
+        self._Status = None
+        self._Weight = None
+        self._CreatedOn = None
+        self._UpdatedOn = None
+        self._Extra = None
+
+    @property
+    def RecordId(self):
+        return self._RecordId
+
+    @RecordId.setter
+    def RecordId(self, RecordId):
+        self._RecordId = RecordId
+
+    @property
+    def ZoneId(self):
+        return self._ZoneId
+
+    @ZoneId.setter
+    def ZoneId(self, ZoneId):
+        self._ZoneId = ZoneId
+
+    @property
+    def SubDomain(self):
+        return self._SubDomain
+
+    @SubDomain.setter
+    def SubDomain(self, SubDomain):
+        self._SubDomain = SubDomain
+
+    @property
+    def RecordType(self):
+        return self._RecordType
+
+    @RecordType.setter
+    def RecordType(self, RecordType):
+        self._RecordType = RecordType
+
+    @property
+    def RecordValue(self):
+        return self._RecordValue
+
+    @RecordValue.setter
+    def RecordValue(self, RecordValue):
+        self._RecordValue = RecordValue
+
+    @property
+    def TTL(self):
+        return self._TTL
+
+    @TTL.setter
+    def TTL(self, TTL):
+        self._TTL = TTL
+
+    @property
+    def MX(self):
+        return self._MX
+
+    @MX.setter
+    def MX(self, MX):
+        self._MX = MX
+
+    @property
+    def Status(self):
+        return self._Status
+
+    @Status.setter
+    def Status(self, Status):
+        self._Status = Status
+
+    @property
+    def Weight(self):
+        return self._Weight
+
+    @Weight.setter
+    def Weight(self, Weight):
+        self._Weight = Weight
+
+    @property
+    def CreatedOn(self):
+        return self._CreatedOn
+
+    @CreatedOn.setter
+    def CreatedOn(self, CreatedOn):
+        self._CreatedOn = CreatedOn
+
+    @property
+    def UpdatedOn(self):
+        return self._UpdatedOn
+
+    @UpdatedOn.setter
+    def UpdatedOn(self, UpdatedOn):
+        self._UpdatedOn = UpdatedOn
+
+    @property
+    def Extra(self):
+        return self._Extra
+
+    @Extra.setter
+    def Extra(self, Extra):
+        self._Extra = Extra
+
+
+    def _deserialize(self, params):
+        self._RecordId = params.get("RecordId")
+        self._ZoneId = params.get("ZoneId")
+        self._SubDomain = params.get("SubDomain")
+        self._RecordType = params.get("RecordType")
+        self._RecordValue = params.get("RecordValue")
+        self._TTL = params.get("TTL")
+        self._MX = params.get("MX")
+        self._Status = params.get("Status")
+        self._Weight = params.get("Weight")
+        self._CreatedOn = params.get("CreatedOn")
+        self._UpdatedOn = params.get("UpdatedOn")
+        self._Extra = params.get("Extra")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SubscribePrivateZoneServiceRequest(AbstractModel):
     """SubscribePrivateZoneService request structure.
 
@@ -2181,7 +2857,7 @@ class SubscribePrivateZoneServiceResponse(AbstractModel):
         r"""
         :param _ServiceStatus: Private DNS service activation status
         :type ServiceStatus: str
-        :param _RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :param _RequestId: The unique request ID, generated by the server, will be returned for every request (if the request fails to reach the server for other reasons, the request will not obtain a RequestId). RequestId is required for locating a problem.
         :type RequestId: str
         """
         self._ServiceStatus = None
