@@ -137,6 +137,9 @@ INVALIDPARAMETERVALUE_BASENETWORKACCESSDENY = 'InvalidParameterValue.BaseNetWork
 # Business verification failed
 INVALIDPARAMETERVALUE_CHECKNOTPASS = 'InvalidParameterValue.CheckNotPass'
 
+# A renaming rule error occurred.
+INVALIDPARAMETERVALUE_INSTANCENAMERULEERROR = 'InvalidParameterValue.InstanceNameRuleError'
+
 # The type of instances requested for purchase is incorrect (TypeId - 1: Cluster Edition; 2: Master-Replica Edition, i.e., the legacy Master-Replica Edition).
 INVALIDPARAMETERVALUE_INVALIDINSTANCETYPEID = 'InvalidParameterValue.InvalidInstanceTypeId'
 
@@ -146,6 +149,9 @@ INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'
 # The requested capacity is out of the purchasable capacity range.
 INVALIDPARAMETERVALUE_MEMSIZENOTINRANGE = 'InvalidParameterValue.MemSizeNotInRange'
 
+# The instance has already been bound.
+INVALIDPARAMETERVALUE_NOTREPEATBIND = 'InvalidParameterValue.NotRepeatBind'
+
 # The password is empty.
 INVALIDPARAMETERVALUE_PASSWORDEMPTY = 'InvalidParameterValue.PasswordEmpty'
 
@@ -182,6 +188,12 @@ INVALIDPARAMETERVALUE_WEEKDAYSISINVALID = 'InvalidParameterValue.WeekDaysIsInval
 # The quota limit has been reached.
 LIMITEXCEEDED = 'LimitExceeded'
 
+# The number of bound instances exceeds the upper limit.
+LIMITEXCEEDED_EXCEEDUPPERLIMIT = 'LimitExceeded.ExceedUpperLimit'
+
+# The bound instance must not be specified.
+LIMITEXCEEDED_INSTANCENOTEMPTY = 'LimitExceeded.InstanceNotEmpty'
+
 # The requested capacity is out of the purchasable specification range (`memSize` should be an integer multiple of 1,024 in MB).
 LIMITEXCEEDED_INVALIDMEMSIZE = 'LimitExceeded.InvalidMemSize'
 
@@ -227,6 +239,9 @@ RESOURCEUNAVAILABLE_ACCOUNTBALANCENOTENOUGH = 'ResourceUnavailable.AccountBalanc
 # The backup has been locked by another task, and the operation cannot be performed temporarily.
 RESOURCEUNAVAILABLE_BACKUPLOCKEDERROR = 'ResourceUnavailable.BackupLockedError'
 
+# Backup and recovery specifications are not supported.
+RESOURCEUNAVAILABLE_BACKUPSPECERROR = 'ResourceUnavailable.BackupSpecError'
+
 # Backup status exception. The operation cannot be performed temporarily. The backup may have expired or been deleted.
 RESOURCEUNAVAILABLE_BACKUPSTATUSABNORMAL = 'ResourceUnavailable.BackupStatusAbnormal'
 
