@@ -26,6 +26,29 @@ class RedisClient(AbstractClient):
     _service = 'redis'
 
 
+    def AddReplicationInstance(self, request):
+        """This API is used to add replication group members.
+
+        :param request: Request instance for AddReplicationInstance.
+        :type request: :class:`tencentcloud.redis.v20180412.models.AddReplicationInstanceRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.AddReplicationInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AddReplicationInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.AddReplicationInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def AllocateWanAddress(self, request):
         """This API is used to enable public network access.
 
@@ -257,7 +280,7 @@ class RedisClient(AbstractClient):
 
 
     def CreateInstanceAccount(self, request):
-        """This API is used to create an instance sub-account.
+        """This API is used to customize the account for accessing the instance.
 
         :param request: Request instance for CreateInstanceAccount.
         :type request: :class:`tencentcloud.redis.v20180412.models.CreateInstanceAccountRequest`
@@ -325,6 +348,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateReplicationGroup(self, request):
+        """This API is used to create a replication group.
+
+        :param request: Request instance for CreateReplicationGroup.
+        :type request: :class:`tencentcloud.redis.v20180412.models.CreateReplicationGroupRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.CreateReplicationGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateReplicationGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateReplicationGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteInstanceAccount(self, request):
         """This API is used to delete an instance sub-account.
 
@@ -371,6 +417,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteReplicationInstance(self, request):
+        """This API is used to remove replication group members. Note: The API is being deprecated. Please use RemoveReplicationInstance instead.
+
+        :param request: Request instance for DeleteReplicationInstance.
+        :type request: :class:`tencentcloud.redis.v20180412.models.DeleteReplicationInstanceRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.DeleteReplicationInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteReplicationInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteReplicationInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAutoBackupConfig(self, request):
         """This API is used to get the configuration rules for an automatic backup.
 
@@ -601,6 +670,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeInstanceEvents(self, request):
+        """This API is used to query the event information on a TecentDB for Redis instance.
+
+        :param request: Request instance for DescribeInstanceEvents.
+        :type request: :class:`tencentcloud.redis.v20180412.models.DescribeInstanceEventsRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.DescribeInstanceEventsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstanceEvents", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstanceEventsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInstanceMonitorBigKey(self, request):
         """The API for querying big keys of a TencentDB for Redis instance was disused on October 31, 2022. For more information, see [API for Querying Instance Big Key Will Be Disused](https://intl.cloud.tencent.com/document/product/239/81005?from_cn_redirect=1).
 
@@ -900,6 +992,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeInstanceSupportFeature(self, request):
+        """This API (DescribeInstanceSupportFeature) is used to query the supported features of the instance.
+
+        :param request: Request instance for DescribeInstanceSupportFeature.
+        :type request: :class:`tencentcloud.redis.v20180412.models.DescribeInstanceSupportFeatureRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.DescribeInstanceSupportFeatureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstanceSupportFeature", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstanceSupportFeatureResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInstanceZoneInfo(self, request):
         """This API is used to query the details of a Redis node.
 
@@ -1521,6 +1636,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyConnectionConfig(self, request):
+        """This API is used to modify the connection configuration of an instance, including the bandwidth and maximum number of connections.
+
+        :param request: Request instance for ModifyConnectionConfig.
+        :type request: :class:`tencentcloud.redis.v20180412.models.ModifyConnectionConfigRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.ModifyConnectionConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyConnectionConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyConnectionConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDBInstanceSecurityGroups(self, request):
         """This API is used to modify the security groups bound to an instance.
 
@@ -1590,6 +1728,52 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstanceAvailabilityZones(self, request):
+        """This API is used to change the availability zone of the instance.
+
+        :param request: Request instance for ModifyInstanceAvailabilityZones.
+        :type request: :class:`tencentcloud.redis.v20180412.models.ModifyInstanceAvailabilityZonesRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.ModifyInstanceAvailabilityZonesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceAvailabilityZones", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceAvailabilityZonesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyInstanceEvent(self, request):
+        """This API is used to modify the operations event execution schedule of an instance.
+
+        :param request: Request instance for ModifyInstanceEvent.
+        :type request: :class:`tencentcloud.redis.v20180412.models.ModifyInstanceEventRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.ModifyInstanceEventResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceEvent", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceEventResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyInstanceParams(self, request):
         """This API is used to modify the parameters of TencentDB for Redis instances
 
@@ -1866,6 +2050,29 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SwitchAccessNewInstance(self, request):
+        """This API is used to immediately switch instances that are in the time window pending switch operation. Users can manually initiate this operation.
+
+        :param request: Request instance for SwitchAccessNewInstance.
+        :type request: :class:`tencentcloud.redis.v20180412.models.SwitchAccessNewInstanceRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.SwitchAccessNewInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SwitchAccessNewInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.SwitchAccessNewInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SwitchInstanceVip(self, request):
         """This API is used to swap the VIPs of instances for instance disaster recovery switch in scenarios where cross-AZ disaster recovery is supported through DTS. After the VIPs of the source and target instances are swapped, the target instance can be written into and the DTS sync task between them will be disconnected.
 
