@@ -116,6 +116,9 @@ FAILEDOPERATION_PUBLISHLAYERVERSION = 'FailedOperation.PublishLayerVersion'
 # You cannot publish a version in the current function state. Please try again when the state is normal.
 FAILEDOPERATION_PUBLISHVERSION = 'FailedOperation.PublishVersion'
 
+# 
+FAILEDOPERATION_QUERYERROR = 'FailedOperation.QueryError'
+
 # The value of ReservedExceedTotal exceeds the limit.
 FAILEDOPERATION_RESERVEDEXCEEDTOTAL = 'FailedOperation.ReservedExceedTotal'
 
@@ -140,6 +143,12 @@ FAILEDOPERATION_UPDATEALIAS = 'FailedOperation.UpdateAlias'
 # You cannot update code in the current function state. Please try again when the state is normal.
 FAILEDOPERATION_UPDATEFUNCTIONCODE = 'FailedOperation.UpdateFunctionCode'
 
+# Failed to update the status
+FAILEDOPERATION_UPDATESTATUS = 'FailedOperation.UpdateStatus'
+
+# The new status is the same as the previous one.
+FAILEDOPERATION_UPDATETRIGGERSTATUS = 'FailedOperation.UpdateTriggerStatus'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
@@ -164,6 +173,9 @@ INTERNALERROR_EXCEPTION = 'InternalError.Exception'
 # Internal system error.
 INTERNALERROR_SYSTEM = 'InternalError.System'
 
+# Log parameter error
+INVALIDPARAMETER_CLS = 'InvalidParameter.Cls'
+
 # The value of `FunctionName` does not conform to the specification. Please fix it and try again. For more information, please visit https://tencentcs.com/5jXKFnBW.
 INVALIDPARAMETER_FUNCTIONNAME = 'InvalidParameter.FunctionName'
 
@@ -173,7 +185,7 @@ INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
 # Invalid request parameter.
 INVALIDPARAMETER_PAYLOAD = 'InvalidParameter.Payload'
 
-# 
+# Request size 
 INVALIDPARAMETER_REQUESTTOOLARGE = 'InvalidParameter.RequestTooLarge'
 
 # RoleCheck parameter error
@@ -185,6 +197,9 @@ INVALIDPARAMETER_ROUTINGCONFIG = 'InvalidParameter.RoutingConfig'
 # Incorrect parameter value.
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# Invalid `Action` value. For more information, go to https://tencentcs.com/5jXKFnBW.
+INVALIDPARAMETERVALUE_ACTION = 'InvalidParameterValue.Action'
+
 # Incorrect `AdditionalVersionWeights` parameter.
 INVALIDPARAMETERVALUE_ADDITIONALVERSIONWEIGHTS = 'InvalidParameterValue.AdditionalVersionWeights'
 
@@ -239,6 +254,9 @@ INVALIDPARAMETERVALUE_COSBUCKETNAME = 'InvalidParameterValue.CosBucketName'
 # The value of CosBucketRegion is invalid. Please modify and try again. See: https://tencentcs.com/5jXKFnBW
 INVALIDPARAMETERVALUE_COSBUCKETREGION = 'InvalidParameterValue.CosBucketRegion'
 
+# COS notification rule conflict
+INVALIDPARAMETERVALUE_COSNOTIFYRULECONFLICT = 'InvalidParameterValue.CosNotifyRuleConflict'
+
 # Invalid CosObjectName.
 INVALIDPARAMETERVALUE_COSOBJECTNAME = 'InvalidParameterValue.CosObjectName'
 
@@ -434,6 +452,12 @@ LIMITEXCEEDED_ALIAS = 'LimitExceeded.Alias'
 # The Cdn usage exceeds the upper limit.
 LIMITEXCEEDED_CDN = 'LimitExceeded.Cdn'
 
+# Reached the upper limit of function versions enabling image acceleration
+LIMITEXCEEDED_CONTAINERIMAGEACCELERATE = 'LimitExceeded.ContainerImageAccelerate'
+
+# Reached the upper limit of function versions enabling image acceleration
+LIMITEXCEEDED_CONTAINERIMAGEACCELERATEQUOTA = 'LimitExceeded.ContainerImageAccelerateQuota'
+
 # If the number of functions exceeds the upper limit, you can apply for an increase by [submitting a ticket](https://intl.cloud.tencent.com/act/event/Online_service?from=scf%7Cindex?from_cn_redirect=1).
 LIMITEXCEEDED_FUNCTION = 'LimitExceeded.Function'
 
@@ -500,6 +524,12 @@ LIMITEXCEEDED_USERTOTALCONCURRENCYMEMORY = 'LimitExceeded.UserTotalConcurrencyMe
 # Missing parameter.
 MISSINGPARAMETER = 'MissingParameter'
 
+# This account has been isolated.
+OPERATIONDENIED_ACCOUNTISOLATE = 'OperationDenied.AccountIsolate'
+
+# 
+OPERATIONDENIED_ACCOUNTNOTEXISTS = 'OperationDenied.AccountNotExists'
+
 # The resource is in use.
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -542,6 +572,9 @@ RESOURCENOTFOUND_ALIAS = 'ResourceNotFound.Alias'
 # The specified `AsyncEvent` was not found. Please create it and try again.
 RESOURCENOTFOUND_ASYNCEVENT = 'ResourceNotFound.AsyncEvent'
 
+# The tag key does not exist.
+RESOURCENOTFOUND_ATTACHEDTAGKEYNOTFOUND = 'ResourceNotFound.AttachedTagKeyNotFound'
+
 # Cdn does not exist.
 RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 
@@ -620,12 +653,18 @@ UNAUTHORIZEDOPERATION_NOTMC = 'UnauthorizedOperation.NotMC'
 # Region error.
 UNAUTHORIZEDOPERATION_REGION = 'UnauthorizedOperation.Region'
 
+# Not authorized to access your COS resources.
+UNAUTHORIZEDOPERATION_ROLE = 'UnauthorizedOperation.Role'
+
 # The `Appid` of TempCos is not consistent with the APPID of the request account.
 UNAUTHORIZEDOPERATION_TEMPCOSAPPID = 'UnauthorizedOperation.TempCosAppid'
 
 # Operation failed.
 UNAUTHORIZEDOPERATION_UPDATEFUNCTIONCODE = 'UnauthorizedOperation.UpdateFunctionCode'
 
+# You are not authorized for the operation.
+UNAUTHORIZEDOPERATION_UPDATETRIGGERSTATUS = 'UnauthorizedOperation.UpdateTriggerStatus'
+
 # Unsupported operation.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
@@ -641,6 +680,12 @@ UNSUPPORTEDOPERATION_COS = 'UnsupportedOperation.Cos'
 # The specified EipFixed does not exist.
 UNSUPPORTEDOPERATION_EIPFIXED = 'UnsupportedOperation.EipFixed'
 
+# Unsupported region.
+UNSUPPORTEDOPERATION_NOTSUPPORTREGION = 'UnsupportedOperation.NotSupportRegion'
+
+# 
+UNSUPPORTEDOPERATION_PUBLISHVERSION = 'UnsupportedOperation.PublishVersion'
+
 # This region is not supported.
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
