@@ -32,16 +32,16 @@ FAILEDOPERATION_JSONPARSEFAIL = 'FailedOperation.JsonParseFail'
 # Marketing SMS messages can only be sent between 8:00 and 22:00 in order not to disturb recipients.
 FAILEDOPERATION_MARKETINGSENDTIMECONSTRAINT = 'FailedOperation.MarketingSendTimeConstraint'
 
-# You cannot apply for a template before you apply for a signature. Please create a signature first as instructed in [Creating Signatures](https://intl.cloud.tencent.com/document/product/382/37794?from_cn_redirect=1#.E5.88.9B.E5.BB.BA.E7.AD.BE.E5.90.8D).
+# You cannot apply for a template before you apply for a signature. Please create a signature first as instructed in [Creating Signature](https://www.tencentcloud.com/document/product/382/35460).
 FAILEDOPERATION_MISSINGSIGNATURE = 'FailedOperation.MissingSignature'
 
-# Unable to identify the signature. Please check whether the signature has been approved. For more information, see the signature approval section in [Getting Started](https://intl.cloud.tencent.com/document/product/382/37745?from_cn_redirect=1).
+# Unable to identify the signature. Please check whether the signature has been approved. For more information, see the signature approval section in [Getting Started](https://www.tencentcloud.com/jp/document/product/382/35452).
 FAILEDOPERATION_MISSINGSIGNATURELIST = 'FailedOperation.MissingSignatureList'
 
 # This signature ID has not been submitted for approval or does not exist, so it cannot be modified. Please check whether the `SignId` is entered correctly.
 FAILEDOPERATION_MISSINGSIGNATURETOMODIFY = 'FailedOperation.MissingSignatureToModify'
 
-# Unable to identify the template. Please check whether the template has been approved. For more information, see the template approval section in [Getting Started](https://intl.cloud.tencent.com/document/product/382/37745?from_cn_redirect=1).
+# Unable to identify the template. Please check whether the template has been approved. For more information, see the template approval section in [Getting Started](https://www.tencentcloud.com/document/product/382/35452).
 FAILEDOPERATION_MISSINGTEMPLATELIST = 'FailedOperation.MissingTemplateList'
 
 # This template ID has not been submitted for approval or does not exist, so it cannot be modified. Please check whether the `TemplateId` is entered correctly.
@@ -137,7 +137,7 @@ INVALIDPARAMETER_INVALIDPARAMETERS = 'InvalidParameter.InvalidParameters'
 # `BeginTime` parameter check failed.
 INVALIDPARAMETERVALUE_BEGINTIMEVERIFYFAIL = 'InvalidParameterValue.BeginTimeVerifyFail'
 
-# The content of the requested SMS message is too long. For message length calculation rule, please see [Mainland China SMS Length Calculation Rule](https://intl.cloud.tencent.com/document/product/382/18058?from_cn_redirect=1).
+# The content of the requested SMS message is too long. For message length calculation rule, please see [SMS Length Calculation Rule](https://www.tencentcloud.com/document/product/382/18052#sms-length-calculation-rule).
 INVALIDPARAMETERVALUE_CONTENTLENGTHLIMIT = 'InvalidParameterValue.ContentLengthLimit'
 
 # `EndTime` parameter check failed.
@@ -158,6 +158,9 @@ INVALIDPARAMETERVALUE_INVALIDINTERNATIONAL = 'InvalidParameterValue.InvalidInter
 # `SignPurpose` field check failed. See the description of this field in the API description. If necessary, you can contact [SMS Helper](https://intl.cloud.tencent.com/document/product/382/3773?from_cn_redirect=1#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81) for assistance.
 INVALIDPARAMETERVALUE_INVALIDSIGNPURPOSE = 'InvalidParameterValue.InvalidSignPurpose'
 
+# SmsType field check failed. See the description of this field in the API description. If necessary, you can contact [SMS Helper](https://www.tencentcloud.com/document/product/382/3773?has_map=2#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81) for assistance.
+INVALIDPARAMETERVALUE_INVALIDSMSTYPE = 'InvalidParameterValue.InvalidSmsType'
+
 # Invalid start time or end time. The reason may be that the requested `SendDateTime` is later than `EndDateTime`.
 INVALIDPARAMETERVALUE_INVALIDSTARTTIME = 'InvalidParameterValue.InvalidStartTime'
 
@@ -170,7 +173,7 @@ INVALIDPARAMETERVALUE_INVALIDUSEDMETHOD = 'InvalidParameterValue.InvalidUsedMeth
 # `Limit` parameter check failed.
 INVALIDPARAMETERVALUE_LIMITVERIFYFAIL = 'InvalidParameterValue.LimitVerifyFail'
 
-# 
+# Marketing messages must include an unsubscribe method.
 INVALIDPARAMETERVALUE_MARKETINGTEMPLATEWITHOUTUNSUBSCRIBE = 'InvalidParameterValue.MarketingTemplateWithoutUnsubscribe'
 
 # `Offset` parameter check failed.
@@ -200,6 +203,9 @@ INVALIDPARAMETERVALUE_TEMPLATEPARAMETERLENGTHLIMIT = 'InvalidParameterValue.Temp
 # The template content contains sensitive words. For more information, please see [Body Template Review Standards](https://intl.cloud.tencent.com/document/product/382/39023?from_cn_redirect=1).
 INVALIDPARAMETERVALUE_TEMPLATEWITHDIRTYWORDS = 'InvalidParameterValue.TemplateWithDirtyWords'
 
+# Notification and Marketing SMS template of Chinese mainland sms are not allowed to have variables. If necessary, you can contact [SMS Helper](https://www.tencentcloud.com/document/product/382/3773?has_map=2#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81) for assistance.
+INVALIDPARAMETERVALUE_UNSUPPORTEDTEMPLATEVARIABLE = 'InvalidParameterValue.UnsupportedTemplateVariable'
+
 # The number of Global SMS messages sent to the specified country/region per day has exceeded the preset limit. You can adjust the message sending limit in **Application Management** > **Basic Configuration** in the SMS console.
 LIMITEXCEEDED_APPCOUNTRYORREGIONDAILYLIMIT = 'LimitExceeded.AppCountryOrRegionDailyLimit'
 
@@ -254,7 +260,7 @@ UNAUTHORIZEDOPERATION_REQUESTPERMISSIONDENY = 'UnauthorizedOperation.RequestPerm
 # This `SdkAppId` is forbidden to provide services. If necessary, you can contact [SMS Helper](https://intl.cloud.tencent.com/document/product/382/3773?from_cn_redirect=1#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81).
 UNAUTHORIZEDOPERATION_SDKAPPIDISDISABLED = 'UnauthorizedOperation.SdkAppIdIsDisabled'
 
-# 
+# If the service is suspended due to outstanding fees, you can log in to Tencent Cloud to recharge and clear the debt on your own.
 UNAUTHORIZEDOPERATION_SERVICESUSPENDDUETOARREARS = 'UnauthorizedOperation.ServiceSuspendDueToArrears'
 
 # Failed to verify `SmsSdkAppId`. Please check whether [SmsSdkAppId](https://console.cloud.tencent.com/smsv2/app-manage) is under the account associated with the [TencentCloud API key](https://console.cloud.tencent.com/cam/capi).
