@@ -32,6 +32,15 @@ FAILEDOPERATION = 'FailedOperation'
 # Unsupported on-cloud recording method.
 FAILEDOPERATION_CRUNSUPPORTMETHOD = 'FailedOperation.CRUnsupportMethod'
 
+# Need to unlock the required ability
+FAILEDOPERATION_NOTABILITY = 'FailedOperation.NotAbility'
+
+# This operation is not allowed, please submit a ticket to contact us
+FAILEDOPERATION_NOTALLOWED = 'FailedOperation.NotAllowed'
+
+# 
+FAILEDOPERATION_NOTRTMPFUNCTION = 'FailedOperation.NotRtmpFunction'
+
 # Query task failed
 FAILEDOPERATION_QUERYTASKINFOFAILED = 'FailedOperation.QueryTaskInfoFailed'
 
@@ -44,12 +53,18 @@ FAILEDOPERATION_ROOMNOTEXIST = 'FailedOperation.RoomNotExist'
 # The application ID does not exist.
 FAILEDOPERATION_SDKAPPIDNOTEXIST = 'FailedOperation.SdkAppIdNotExist'
 
+# There is no resource for this SdkAppId  In this AppId
+FAILEDOPERATION_SDKAPPIDNOTUNDERAPPID = 'FailedOperation.SdkAppIdNotUnderAppId'
+
 # Task already exists
 FAILEDOPERATION_TASKEXIST = 'FailedOperation.TaskExist'
 
 # Task has ended when calling the interface.
 FAILEDOPERATION_TASKFINISHED = 'FailedOperation.TaskFinished'
 
+# The task does not exist.
+FAILEDOPERATION_TASKNOTEXIST = 'FailedOperation.TaskNotExist'
+
 # The user is not in the room.
 FAILEDOPERATION_USERNOTEXIST = 'FailedOperation.UserNotExist'
 
@@ -137,6 +152,9 @@ INVALIDPARAMETER_STARTTSOVERSIZE = 'InvalidParameter.StartTsOversize'
 # StrRoomId parameter error.
 INVALIDPARAMETER_STRROOMID = 'InvalidParameter.StrRoomId'
 
+# Invalid StreamUrl format
+INVALIDPARAMETER_STREAMURL = 'InvalidParameter.StreamUrl'
+
 # TaskId parameter error.
 INVALIDPARAMETER_TASKID = 'InvalidParameter.TaskId'
 
@@ -152,6 +170,12 @@ INVALIDPARAMETER_USERIDS = 'InvalidParameter.UserIds'
 # The number of users exceeds 6.
 INVALIDPARAMETER_USERIDSMORETHANSIX = 'InvalidParameter.UserIdsMorethanSix'
 
+# UserSig is expired or wrong
+INVALIDPARAMETER_USERSIG = 'InvalidParameter.UserSig'
+
+# 
+INVALIDPARAMETER_USERSIGNOTADMIN = 'InvalidParameter.UserSigNotAdmin'
+
 # Invalid RoomId.
 INVALIDPARAMETERVALUE_ROOMID = 'InvalidParameterValue.RoomId'
 
