@@ -335,6 +335,9 @@ INVALIDPARAMETERVALUE_INTERVAL = 'InvalidParameterValue.Interval'
 # Invalid `OperationType`.
 INVALIDPARAMETERVALUE_INVALIDOPERATIONTYPE = 'InvalidParameterValue.InvalidOperationType'
 
+# 
+INVALIDPARAMETERVALUE_ISPERSISTENCE = 'InvalidParameterValue.IsPersistence'
+
 # Invalid `Isps`.
 INVALIDPARAMETERVALUE_ISPS = 'InvalidParameterValue.Isps'
 
@@ -395,12 +398,21 @@ INVALIDPARAMETERVALUE_OPERATION = 'InvalidParameterValue.Operation'
 # Parameter error: Current storage class error.
 INVALIDPARAMETERVALUE_ORIGINALSTORAGECLASS = 'InvalidParameterValue.OriginalStorageClass'
 
+# 
+INVALIDPARAMETERVALUE_OUTPUTMEDIATYPE = 'InvalidParameterValue.OutputMediaType'
+
 # Incorrect parameter value: invalid `ParentId`
 INVALIDPARAMETERVALUE_PARENTID = 'InvalidParameterValue.ParentId'
 
 # Incorrect parameter value: the face image format is incorrect.
 INVALIDPARAMETERVALUE_PICFORMATERROR = 'InvalidParameterValue.PicFormatError'
 
+# 
+INVALIDPARAMETERVALUE_PRECISION = 'InvalidParameterValue.Precision'
+
+# 
+INVALIDPARAMETERVALUE_PROCEDURE = 'InvalidParameterValue.Procedure'
+
 # The task flow template name is invalid.
 INVALIDPARAMETERVALUE_PROCEDURENAME = 'InvalidParameterValue.ProcedureName'
 
