@@ -380,7 +380,7 @@ INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'
 # The traffic package ID is invalid.
 INVALIDPARAMETERVALUE_TRAFFICPACKAGEIDMALFORMED = 'InvalidParameterValue.TrafficPackageIdMalformed'
 
-# u200dThis traffic package is not found.
+# This traffic package is not found.
 INVALIDPARAMETERVALUE_TRAFFICPACKAGENOTFOUND = 'InvalidParameterValue.TrafficPackageNotFound'
 
 # The specified traffic package does not support this operation. 
@@ -539,6 +539,9 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # The IP range resources are insufficient.
 RESOURCEINSUFFICIENT_CIDRBLOCK = 'ResourceInsufficient.CidrBlock'
 
+# 
+RESOURCEINSUFFICIENT_INSTANCE = 'ResourceInsufficient.Instance'
+
 # The subnet does not have sufficient IPs.
 RESOURCEINSUFFICIENT_SUBNET = 'ResourceInsufficient.Subnet'
 
@@ -725,6 +728,9 @@ UNSUPPORTEDOPERATION_INSTANCESTATENOTSUPPORTED = 'UnsupportedOperation.InstanceS
 # Insufficient account balance.
 UNSUPPORTEDOPERATION_INSUFFICIENTFUNDS = 'UnsupportedOperation.InsufficientFunds'
 
+# 
+UNSUPPORTEDOPERATION_INSUFFICIENTINTERNETSERVICEPROVIDERS = 'UnsupportedOperation.InsufficientInternetServiceProviders'
+
 # Unsupported operation.
 UNSUPPORTEDOPERATION_INVALIDACTION = 'UnsupportedOperation.InvalidAction'
 
@@ -812,6 +818,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTATTACHEDGEANDCROSSBORDERINSTANCE = 'UnsupportedOp
 # The default route table cannot be deleted.
 UNSUPPORTEDOPERATION_NOTSUPPORTDELETEDEFAULTROUTETABLE = 'UnsupportedOperation.NotSupportDeleteDefaultRouteTable'
 
+# 
+UNSUPPORTEDOPERATION_NOTSUPPORTZONE = 'UnsupportedOperation.NotSupportZone'
+
 # This type of addresses cannot be released.
 UNSUPPORTEDOPERATION_NOTSUPPORTEDADDRESSIPSCHARGETYPE = 'UnsupportedOperation.NotSupportedAddressIpsChargeType'
 
